<?php
/**
 * Theme Functions.php
 *
 * All functions of ANISBD Theme.
*/

/**
 * ---------------------------------------------------
 * Step 1.0 - Setting Up Theme's Default content width
 * ---------------------------------------------------
*/
if ( ! isset( $content_width ) ) {
	$content_width = 600;
}

/**
 * -------------------------------------
 * Step 2.0 - Define Necessary Constants
 * -------------------------------------
*/
define('THEME_ROOT', get_stylesheet_directory_uri());
define('IMAGES', THEME_ROOT.'/images');
define('CSS', THEME_ROOT.'/css');
define('JS', THEME_ROOT.'/js');
define('FONTS', THEME_ROOT.'/font');

/**
 * ------------------------------------------
 * Step 3.0 - Enqueue Stylesheet & Javascript
 * ------------------------------------------
*/
function anisbd_basic_all() {
	// Load our main stylesheet.
	wp_enqueue_style( 'main_css', get_stylesheet_uri() );
    
    // Add required stylesheet
    wp_enqueue_style( 'less_css', get_template_directory_uri() . '/css/less.css', array(), '1.0' );
    wp_enqueue_style( 'fonts_css', get_template_directory_uri() . '/css/fontello.css', array(), '1.0' );

	/* Load basic Bootstrap javascript */
	wp_enqueue_script( 'res_nav_js', get_template_directory_uri() . '/js/res-nav.js', array('jquery'), '1.0', true );

	// Load Comment reply on single post
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'anisbd_basic_all' );

/**
 * ---------------------------------
 * Step 4.0 - Installing Theme Setup
 * ---------------------------------
*/

function anisbd_setup_theme() {
	/*
	 * Makes Bharat available for translation.
	 *
	 * Translations can be added to the /languages/ directory.
	 * If you're building a theme based on Bharat, use a find and replace
	 * to change 'bharat' to the name of your theme in all the template files.
	 */
	load_theme_textdomain( 'anisbd', get_template_directory() . '/languages' );

	// This theme styles the visual editor with editor-style.css to match the theme style.
	add_editor_style();

	// Adds RSS feed links to <head> for posts and comments.
	add_theme_support( 'automatic-feed-links' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menu( 'top-menu', __( 'Top Menu', 'anisbd' ) );

	// Add theme support for title tag
	add_theme_support( 'title-tag' );

	/*
	 * This theme supports custom background color and image,
	 * and here we also set up the default background color.
	 */
	add_theme_support( 'custom-background', array(
		'default-color' => '#e6e6e6',
		'header-text'			=> true,
		'default-text-color'		=> '444',
	) );
	
	/* Add theme support for custom-header */
	$args = array(
		'width'         => 1200,
		'height'        => 250,
		'uploads'       => true,
	);
	add_theme_support( 'custom-header', $args );

	// This theme uses a custom image size for featured images, displayed on "standard" posts.
	add_theme_support( 'post-thumbnails' );
	set_post_thumbnail_size( 450, 600 );
}
add_action( 'after_setup_theme', 'anisbd_setup_theme' );

/**
 * ----------------------
 * Step 5.0 - Filter Menu
 * ----------------------
 *
 * Filter the page menu arguments.
 *
 * Makes our wp_nav_menu() to fallback - wp_page_menu() - show a home link.
 *
 * @since anisbd 1.0
 */
function anisbd_page_menu_args( $args ) {
	if ( ! isset( $args['show_home'] ) )
		$args['show_home'] = true;
	return $args;
}
add_filter( 'wp_page_menu_args', 'anisbd_page_menu_args' );

/**
 * --------------------------
 * Step 6.0 - Filter WP title
 * --------------------------
 *
 * Register sidebars.
 *
 * Registers our widgets area.
 *
 * @since anisbd 1.0
 */
function anisbd_widgets_init() {
	register_sidebar( array(
		'name' => __( 'Main Sidebar Left', 'anisbd' ),
		'id' => 'sidebar-1',
		'description' => __( 'Appears on first sidebar on left where widgets are shown.', 'anisbd' ),
		'before_widget' => '<aside id="%1$s" class="sidebar widget %2$s">',
		'after_widget' => '</aside>',
		'before_title' => '<h2>',
		'after_title' => '</h2>',
	) );
}
add_action( 'widgets_init', 'anisbd_widgets_init' );

/**
 * -------------------------------------
 * Step 7.0 - Filter Image to responsive
 * -------------------------------------
 *
 * @since anisbd 1.0
 */
function add_image_responsive_class($content) {
   global $post;
   $pattern ="/<img(.*?)class=\"(.*?)\"(.*?)>/i";
   $replacement = '<img$1class="$2 img-responsive"$3>';
   $content = preg_replace($pattern, $replacement, $content);
   return $content;
}
add_filter('the_content', 'add_image_responsive_class');

/**
 * --------------------------------
 * Step 8.0 - Custom comment form
 * --------------------------------
 */
if ( ! function_exists( 'anisbd_comment' ) ) :
/**
 * Template for comments and pingbacks.
 *
 * To override this walker in a child theme without modifying the comments template
 * simply create your own anisbd_comment(), and that function will be used instead.
 *
 * Used as a callback by wp_list_comments() for displaying the comments.
 *
 * @since Anisbd 1.0
 */
function anisbd_comment( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
	switch ( $comment->comment_type ) :
		case 'pingback' :
		case 'trackback' :
		// Display trackbacks differently than normal comments.
	?>
	<li <?php comment_class(); ?> id="comment-<?php comment_ID(); ?>">
		<p><?php _e( 'Pingback:', 'anisbd' ); ?> <?php comment_author_link(); ?> <?php edit_comment_link( __( '(Edit)', 'anisbd' ), '<span class="edit-link">', '</span>' ); ?></p>
	<?php
			break;
		default :
		// Proceed with normal comments.
		global $post;
	?>
	<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
		<div id="comment-<?php comment_ID(); ?>" class="comment">
			<div class="comment-meta comment-author vcard">
				<?php
					echo get_avatar( $comment, 44 );
					printf( '<cite><b class="fn">%1$s</b> %2$s</cite>',
						get_comment_author_link(),
						// If current post author is also comment author, make it known visually.
						( $comment->user_id === $post->post_author ) ? '<span>' . __( 'Post author', 'anisbd' ) . '</span>' : ''
					);
					printf( '<a href="%1$s"><time datetime="%2$s">%3$s</time></a>',
						esc_url( get_comment_link( $comment->comment_ID ) ),
						get_comment_time( 'c' ),
						/* translators: 1: date, 2: time */
						sprintf( __( '%1$s at %2$s', 'anisbd' ), get_comment_date(), get_comment_time() )
					);
				?>
			</div><!-- .comment-meta -->

			<?php if ( '0' == $comment->comment_approved ) : ?>
				<p class="comment-awaiting-moderation"><?php _e( 'Your comment is awaiting moderation.', 'anisbd' ); ?></p>
			<?php endif; ?>

			<div class="comment-content comment">
				<?php comment_text(); ?>
				<?php edit_comment_link( __( 'Edit', 'anisbd' ), '<p class="edit-link">', '</p>' ); ?>
			</div><!-- .comment-content -->

			<div class="reply">
				<?php comment_reply_link( array_merge( $args, array( 'reply_text' => __( 'Reply', 'anisbd' ), 'after' => ' <span>&darr;</span>', 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
			</div><!-- .reply -->
		</div><!-- #comment-## -->
	<?php
		break;
	endswitch; // end comment_type check
}
endif;

/**
 * ------------------------------
 * Step 9.0 - Custom Pagination
 * ------------------------------
 */
function pagenavi( $p = 2 ) { // pages will be show before and after current page
  if ( is_singular() ) return; // don't show in single page
  global $wp_query, $paged;
  $max_page = $wp_query->max_num_pages;
  if ( $max_page == 1 ) return; // don't show when only one page
  if ( empty( $paged ) ) $paged = 1;
  // echo '<span class="pages">Page: ' . $paged . ' of ' . $max_page . ' </span> '; // pages
  if ( $paged > $p + 1 ) p_link( 1, 'First' );
echo'<ul class="pagination">';
  if ( $paged > $p + 2 ) echo '... ';
  for( $i = $paged - $p; $i <= $paged + $p; $i++ ) { // Middle pages
    if ( $i > 0 && $i <= $max_page ) $i == $paged ? print "<li><span class='page-numbers current'>{$i}</span></li> " : p_link( $i );
  }
  if ( $paged < $max_page - $p - 1 ) echo '... ';
  if ( $paged < $max_page - $p ) p_link( $max_page, 'Last' );
 echo'</ul>';
}
function p_link( $i, $title = '' ) {
  if ( $title == '' ) $title = "Page {$i}";
  echo "<li><a class='page-numbers' href='", esc_html( get_pagenum_link( $i ) ), "' title='{$title}'>{$i}</a></li>";
}


/**
 * -------------------------
 * Step 10.0 - Add read more
 * -------------------------
 */
function arb_excerpt_more( $more ) {
	return ' <a class="read-more" href="'. get_permalink( get_the_ID() ) . '">' . __('Continue Reading', 'your-text-domain') . '</a>';
}
add_filter( 'excerpt_more', 'arb_excerpt_more' );

/**
 * -----------------------------------
 * Step 11.0 - Customizer live preview
 * -----------------------------------
 * Used by hook: 'customize_preview_init'
 * 
 * @see add_action('customize_preview_init',$func)
 */
function arbblogging_customizer_live_preview()
{
	wp_enqueue_script( 
		  'arb-themecustomizer',			//Give the script an ID
		  get_template_directory_uri().'/js/theme-customizer.js',//Point to file
		  array( 'jquery','customize-preview' ),	//Define dependencies
		  '4.1',						//Define a version (optional) 
		  true						//Put script in footer?
	);
}
add_action( 'customize_preview_init', 'arbblogging_customizer_live_preview' );

/**
 * --------------------------
 * Step 12.0 - Required files
 * --------------------------
 */
get_template_part('inc/customizer');
?>